@@ -5,8 +5,7 @@
 #    @Pip-Library: https://pypi.org/project/ndn-svs/
 
 # NDN Imports
-from ndn.encoding import Component
-from ndn.encoding import TlvModel, UintField, BytesField, DecodeError
+from ndn.encoding import Component, TlvModel, UintField, BytesField, DecodeError
 
 # Class Type: a tlv structure for encoding
 # Class Purpose:
@@ -23,11 +22,11 @@ class MetaData:
     __slots__ = ('source','tseqno','nopcks')
     def __init__(self, comp:Component=None) -> None:
         try:
-            model = MetaDataModel.parse(bytes(Component.get_value(comp)))
+            model:MetaDataModel = MetaDataModel.parse(bytes(Component.get_value(comp)))
             self.source, self.tseqno, self.nopcks = model.source, model.tseqno, model.nopcks
         except (ValueError,TypeError,IndexError,DecodeError):
             self.source, self.tseqno, self.nopcks = b'', 0, 0
     def encode(self) -> Component:
-        model = MetaDataModel()
+        model:MetaDataModel = MetaDataModel()
         model.source, model.tseqno, model.nopcks = self.source, self.tseqno, self.nopcks
         return Component.from_bytes(model.encode())
\ No newline at end of file
